==> dclib-0.3.19.tar.bz2: dclib-0.3.19/dclib/csearchsocket.cpp <==
/***************************************************************************
                          csearchsocket.cpp  -  description
                             -------------------
    begin                : Thu May 27 2004
    copyright            : (C) 2004 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <stdio.h>

#include "dcos.h"
#include "dclib.h"
#include "core/cstring.h"
#include "cmessagehandler.h"

#include "csearchsocket.h"

/** */
CSearchSocket::CSearchSocket()
{
	m_pCallback = 0;
}

/** */
CSearchSocket::~CSearchSocket()
{
	SetCallBackFunction(0);
}

/** */
int CSearchSocket::HandleMessage( char * c, int )
{
	int p=0;
	eDCMessage type;
	CObject * Object = 0;
	CMessageHandler MessageHandler;
	CString s;
	int err;
	s = c;

	while( (type=MessageHandler.Parse(&s,p,&Object)) != DC_MESSAGE_PARSE_ERROR )
	{
		switch (type)
		{
			case DC_MESSAGE_SEARCHRESULT:
			{
				break;
			}

			default:
			{
				// remove message
				delete Object;
				Object = 0;
				break;
			}
		}

		if (Object)
		{
			err = -1;

			((CDCMessage*)Object)->m_eType = type;

			if ( m_pCallback != 0 )
			{
				err = m_pCallback->notify( this, Object );
			}

			if ( err == -1 )
			{
				printf("CSearchSocket::HandleMessage: CallBack failed (state)...\n");
				delete Object;
			}
		}
	}

	return 0;
}

/** */
void CSearchSocket::DataAvailable( const char * buffer, int len )
{
	CString m_sBuffer;
	
	m_sBuffer = buffer;

	// add traffic control
	CSocket::m_Traffic.AddTraffic(ettCONTROLRX,len);

	// add '|' for parser
	m_sBuffer += '|';

	HandleMessage( (char*)m_sBuffer.Data(), m_sBuffer.Length() );
}

==> dclib-0.3.21.tar.bz2: dclib-0.3.21/dclib/csearchsocket.cpp <==
/***************************************************************************
                          csearchsocket.cpp  -  description
                             -------------------
    begin                : Thu May 27 2004
    copyright            : (C) 2004 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "csearchsocket.h"

#include <stdio.h>

#include "dclib.h"
#include "core/cstring.h"
#include "cmessagehandler.h"

#include "dcobject.h"

/** */
CSearchSocket::CSearchSocket()
{
	m_pCallback = 0;
}

/** */
CSearchSocket::~CSearchSocket()
{
	SetCallBackFunction(0);
}

/** */
int CSearchSocket::HandleMessage( char * c, int )
{
	int p=0;
	eDCMessage type;
	CDCMessage * Object = 0;
	CMessageHandler MessageHandler;
	CString s;
	int err;
	s = c;

	while( (type=MessageHandler.Parse(&s,p,&Object)) != DC_MESSAGE_PARSE_ERROR )
	{
		switch (type)
		{
			case DC_MESSAGE_SEARCHRESULT:
			{
				break;
			}

			default:
			{
				// remove message
				delete Object;
				Object = 0;
				break;
			}
		}

		if (Object)
		{
			err = -1;

			if ( m_pCallback != 0 )
			{
				err = m_pCallback->notify( Object );
			}

			if ( err == -1 )
			{
				printf("CSearchSocket::HandleMessage: CallBack failed (state)...\n");
				delete Object;
			}
		}
	}

	return 0;
}

/** */
void CSearchSocket::DataAvailable( const char * buffer, int len )
{
	CString m_sBuffer;
	
	m_sBuffer = buffer;

	// add traffic control
	CSocket::m_Traffic.AddTraffic(ettCONTROLRX,len);

	// add '|' for parser
	m_sBuffer += '|';

	HandleMessage( (char*)m_sBuffer.Data(), m_sBuffer.Length() );
}
